# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['EventServiceDiscoveryArgs', 'EventServiceDiscovery']

@pulumi.input_type
class EventServiceDiscoveryArgs:
    def __init__(__self__, *,
                 taskid: pulumi.Input[_builtins.str],
                 nodes: Optional[pulumi.Input[Sequence[pulumi.Input['EventServiceDiscoveryNodeArgs']]]] = None):
        """
        The set of arguments for constructing a EventServiceDiscovery resource.
        :param pulumi.Input[_builtins.str] taskid: servicediscovery endpoint ( Below example shows how to create endpoing using AS3 )
        :param pulumi.Input[Sequence[pulumi.Input['EventServiceDiscoveryNodeArgs']]] nodes: Map of node which will be added to pool which will be having node name(id),node address(ip) and node port(port)
               
               For more information, please refer below document
               https://clouddocs.f5.com/products/extensions/f5-appsvcs-extension/latest/declarations/discovery.html?highlight=service%20discovery#event-driven-service-discovery
               
               Below example shows how to use event-driven service discovery, introduced in AS3 3.9.0.
               
               With event-driven service discovery, you POST a declaration with the addressDiscovery property set to event. This creates a new endpoint which you can use to add nodes that does not require an AS3 declaration, so it can be more efficient than using PATCH or POST to add nodes.
               
               When you use the event value for addressDiscovery, the system creates the new endpoint with the following syntax: https://<host>/mgmt/shared/service-discovery/task/~<tenant name>~<application name>~<pool name>/nodes.
               
               For example, in the following declaration, assuming 192.0.2.14 is our BIG-IP, the endpoint that is created is: https://192.0.2.14/mgmt/shared/service-discovery/task/~Sample_event_sd~My_app~My_pool/nodes
               
               Once the endpoint is created( taskid ), you can use it to add nodes to the BIG-IP pool
               First we show the initial declaration to POST to the BIG-IP system.
               
               {
               "class": "ADC",
               "schemaVersion": "3.9.0",
               "id": "Pool",
               "Sample_event_sd": {
               "class": "Tenant",
               "My_app": {
               "class": "Application",
               "My_pool": {
               "class": "Pool",
               "members": [
               {
               "servicePort": 8080,
               "addressDiscovery": "static",
               "serverAddresses": [
               "192.0.2.2"
               ]
               },
               {
               "servicePort": 8080,
               "addressDiscovery": "event"
               }
               ]
               }
               }
               }
               }
               
               
               Once the declaration has been sent to the BIG-IP, we can use taskid/id ( ~Sample_event_sd~My_app~My_pool" ) and node list for the resource to dynamically update the node list.
        """
        pulumi.set(__self__, "taskid", taskid)
        if nodes is not None:
            pulumi.set(__self__, "nodes", nodes)

    @_builtins.property
    @pulumi.getter
    def taskid(self) -> pulumi.Input[_builtins.str]:
        """
        servicediscovery endpoint ( Below example shows how to create endpoing using AS3 )
        """
        return pulumi.get(self, "taskid")

    @taskid.setter
    def taskid(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "taskid", value)

    @_builtins.property
    @pulumi.getter
    def nodes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['EventServiceDiscoveryNodeArgs']]]]:
        """
        Map of node which will be added to pool which will be having node name(id),node address(ip) and node port(port)

        For more information, please refer below document
        https://clouddocs.f5.com/products/extensions/f5-appsvcs-extension/latest/declarations/discovery.html?highlight=service%20discovery#event-driven-service-discovery

        Below example shows how to use event-driven service discovery, introduced in AS3 3.9.0.

        With event-driven service discovery, you POST a declaration with the addressDiscovery property set to event. This creates a new endpoint which you can use to add nodes that does not require an AS3 declaration, so it can be more efficient than using PATCH or POST to add nodes.

        When you use the event value for addressDiscovery, the system creates the new endpoint with the following syntax: https://<host>/mgmt/shared/service-discovery/task/~<tenant name>~<application name>~<pool name>/nodes.

        For example, in the following declaration, assuming 192.0.2.14 is our BIG-IP, the endpoint that is created is: https://192.0.2.14/mgmt/shared/service-discovery/task/~Sample_event_sd~My_app~My_pool/nodes

        Once the endpoint is created( taskid ), you can use it to add nodes to the BIG-IP pool
        First we show the initial declaration to POST to the BIG-IP system.

        {
        "class": "ADC",
        "schemaVersion": "3.9.0",
        "id": "Pool",
        "Sample_event_sd": {
        "class": "Tenant",
        "My_app": {
        "class": "Application",
        "My_pool": {
        "class": "Pool",
        "members": [
        {
        "servicePort": 8080,
        "addressDiscovery": "static",
        "serverAddresses": [
        "192.0.2.2"
        ]
        },
        {
        "servicePort": 8080,
        "addressDiscovery": "event"
        }
        ]
        }
        }
        }
        }


        Once the declaration has been sent to the BIG-IP, we can use taskid/id ( ~Sample_event_sd~My_app~My_pool" ) and node list for the resource to dynamically update the node list.
        """
        return pulumi.get(self, "nodes")

    @nodes.setter
    def nodes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['EventServiceDiscoveryNodeArgs']]]]):
        pulumi.set(self, "nodes", value)


@pulumi.input_type
class _EventServiceDiscoveryState:
    def __init__(__self__, *,
                 nodes: Optional[pulumi.Input[Sequence[pulumi.Input['EventServiceDiscoveryNodeArgs']]]] = None,
                 taskid: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering EventServiceDiscovery resources.
        :param pulumi.Input[Sequence[pulumi.Input['EventServiceDiscoveryNodeArgs']]] nodes: Map of node which will be added to pool which will be having node name(id),node address(ip) and node port(port)
               
               For more information, please refer below document
               https://clouddocs.f5.com/products/extensions/f5-appsvcs-extension/latest/declarations/discovery.html?highlight=service%20discovery#event-driven-service-discovery
               
               Below example shows how to use event-driven service discovery, introduced in AS3 3.9.0.
               
               With event-driven service discovery, you POST a declaration with the addressDiscovery property set to event. This creates a new endpoint which you can use to add nodes that does not require an AS3 declaration, so it can be more efficient than using PATCH or POST to add nodes.
               
               When you use the event value for addressDiscovery, the system creates the new endpoint with the following syntax: https://<host>/mgmt/shared/service-discovery/task/~<tenant name>~<application name>~<pool name>/nodes.
               
               For example, in the following declaration, assuming 192.0.2.14 is our BIG-IP, the endpoint that is created is: https://192.0.2.14/mgmt/shared/service-discovery/task/~Sample_event_sd~My_app~My_pool/nodes
               
               Once the endpoint is created( taskid ), you can use it to add nodes to the BIG-IP pool
               First we show the initial declaration to POST to the BIG-IP system.
               
               {
               "class": "ADC",
               "schemaVersion": "3.9.0",
               "id": "Pool",
               "Sample_event_sd": {
               "class": "Tenant",
               "My_app": {
               "class": "Application",
               "My_pool": {
               "class": "Pool",
               "members": [
               {
               "servicePort": 8080,
               "addressDiscovery": "static",
               "serverAddresses": [
               "192.0.2.2"
               ]
               },
               {
               "servicePort": 8080,
               "addressDiscovery": "event"
               }
               ]
               }
               }
               }
               }
               
               
               Once the declaration has been sent to the BIG-IP, we can use taskid/id ( ~Sample_event_sd~My_app~My_pool" ) and node list for the resource to dynamically update the node list.
        :param pulumi.Input[_builtins.str] taskid: servicediscovery endpoint ( Below example shows how to create endpoing using AS3 )
        """
        if nodes is not None:
            pulumi.set(__self__, "nodes", nodes)
        if taskid is not None:
            pulumi.set(__self__, "taskid", taskid)

    @_builtins.property
    @pulumi.getter
    def nodes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['EventServiceDiscoveryNodeArgs']]]]:
        """
        Map of node which will be added to pool which will be having node name(id),node address(ip) and node port(port)

        For more information, please refer below document
        https://clouddocs.f5.com/products/extensions/f5-appsvcs-extension/latest/declarations/discovery.html?highlight=service%20discovery#event-driven-service-discovery

        Below example shows how to use event-driven service discovery, introduced in AS3 3.9.0.

        With event-driven service discovery, you POST a declaration with the addressDiscovery property set to event. This creates a new endpoint which you can use to add nodes that does not require an AS3 declaration, so it can be more efficient than using PATCH or POST to add nodes.

        When you use the event value for addressDiscovery, the system creates the new endpoint with the following syntax: https://<host>/mgmt/shared/service-discovery/task/~<tenant name>~<application name>~<pool name>/nodes.

        For example, in the following declaration, assuming 192.0.2.14 is our BIG-IP, the endpoint that is created is: https://192.0.2.14/mgmt/shared/service-discovery/task/~Sample_event_sd~My_app~My_pool/nodes

        Once the endpoint is created( taskid ), you can use it to add nodes to the BIG-IP pool
        First we show the initial declaration to POST to the BIG-IP system.

        {
        "class": "ADC",
        "schemaVersion": "3.9.0",
        "id": "Pool",
        "Sample_event_sd": {
        "class": "Tenant",
        "My_app": {
        "class": "Application",
        "My_pool": {
        "class": "Pool",
        "members": [
        {
        "servicePort": 8080,
        "addressDiscovery": "static",
        "serverAddresses": [
        "192.0.2.2"
        ]
        },
        {
        "servicePort": 8080,
        "addressDiscovery": "event"
        }
        ]
        }
        }
        }
        }


        Once the declaration has been sent to the BIG-IP, we can use taskid/id ( ~Sample_event_sd~My_app~My_pool" ) and node list for the resource to dynamically update the node list.
        """
        return pulumi.get(self, "nodes")

    @nodes.setter
    def nodes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['EventServiceDiscoveryNodeArgs']]]]):
        pulumi.set(self, "nodes", value)

    @_builtins.property
    @pulumi.getter
    def taskid(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        servicediscovery endpoint ( Below example shows how to create endpoing using AS3 )
        """
        return pulumi.get(self, "taskid")

    @taskid.setter
    def taskid(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "taskid", value)


@pulumi.type_token("f5bigip:index/eventServiceDiscovery:EventServiceDiscovery")
class EventServiceDiscovery(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 nodes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EventServiceDiscoveryNodeArgs', 'EventServiceDiscoveryNodeArgsDict']]]]] = None,
                 taskid: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        test = f5bigip.EventServiceDiscovery("test",
            taskid="~Sample_event_sd~My_app~My_pool",
            nodes=[
                {
                    "id": "newNode1",
                    "ip": "192.168.2.3",
                    "port": 8080,
                },
                {
                    "id": "newNode2",
                    "ip": "192.168.2.4",
                    "port": 8080,
                },
            ])
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['EventServiceDiscoveryNodeArgs', 'EventServiceDiscoveryNodeArgsDict']]]] nodes: Map of node which will be added to pool which will be having node name(id),node address(ip) and node port(port)
               
               For more information, please refer below document
               https://clouddocs.f5.com/products/extensions/f5-appsvcs-extension/latest/declarations/discovery.html?highlight=service%20discovery#event-driven-service-discovery
               
               Below example shows how to use event-driven service discovery, introduced in AS3 3.9.0.
               
               With event-driven service discovery, you POST a declaration with the addressDiscovery property set to event. This creates a new endpoint which you can use to add nodes that does not require an AS3 declaration, so it can be more efficient than using PATCH or POST to add nodes.
               
               When you use the event value for addressDiscovery, the system creates the new endpoint with the following syntax: https://<host>/mgmt/shared/service-discovery/task/~<tenant name>~<application name>~<pool name>/nodes.
               
               For example, in the following declaration, assuming 192.0.2.14 is our BIG-IP, the endpoint that is created is: https://192.0.2.14/mgmt/shared/service-discovery/task/~Sample_event_sd~My_app~My_pool/nodes
               
               Once the endpoint is created( taskid ), you can use it to add nodes to the BIG-IP pool
               First we show the initial declaration to POST to the BIG-IP system.
               
               {
               "class": "ADC",
               "schemaVersion": "3.9.0",
               "id": "Pool",
               "Sample_event_sd": {
               "class": "Tenant",
               "My_app": {
               "class": "Application",
               "My_pool": {
               "class": "Pool",
               "members": [
               {
               "servicePort": 8080,
               "addressDiscovery": "static",
               "serverAddresses": [
               "192.0.2.2"
               ]
               },
               {
               "servicePort": 8080,
               "addressDiscovery": "event"
               }
               ]
               }
               }
               }
               }
               
               
               Once the declaration has been sent to the BIG-IP, we can use taskid/id ( ~Sample_event_sd~My_app~My_pool" ) and node list for the resource to dynamically update the node list.
        :param pulumi.Input[_builtins.str] taskid: servicediscovery endpoint ( Below example shows how to create endpoing using AS3 )
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: EventServiceDiscoveryArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_f5bigip as f5bigip

        test = f5bigip.EventServiceDiscovery("test",
            taskid="~Sample_event_sd~My_app~My_pool",
            nodes=[
                {
                    "id": "newNode1",
                    "ip": "192.168.2.3",
                    "port": 8080,
                },
                {
                    "id": "newNode2",
                    "ip": "192.168.2.4",
                    "port": 8080,
                },
            ])
        ```

        :param str resource_name: The name of the resource.
        :param EventServiceDiscoveryArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(EventServiceDiscoveryArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 nodes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EventServiceDiscoveryNodeArgs', 'EventServiceDiscoveryNodeArgsDict']]]]] = None,
                 taskid: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = EventServiceDiscoveryArgs.__new__(EventServiceDiscoveryArgs)

            __props__.__dict__["nodes"] = nodes
            if taskid is None and not opts.urn:
                raise TypeError("Missing required property 'taskid'")
            __props__.__dict__["taskid"] = taskid
        super(EventServiceDiscovery, __self__).__init__(
            'f5bigip:index/eventServiceDiscovery:EventServiceDiscovery',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            nodes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EventServiceDiscoveryNodeArgs', 'EventServiceDiscoveryNodeArgsDict']]]]] = None,
            taskid: Optional[pulumi.Input[_builtins.str]] = None) -> 'EventServiceDiscovery':
        """
        Get an existing EventServiceDiscovery resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['EventServiceDiscoveryNodeArgs', 'EventServiceDiscoveryNodeArgsDict']]]] nodes: Map of node which will be added to pool which will be having node name(id),node address(ip) and node port(port)
               
               For more information, please refer below document
               https://clouddocs.f5.com/products/extensions/f5-appsvcs-extension/latest/declarations/discovery.html?highlight=service%20discovery#event-driven-service-discovery
               
               Below example shows how to use event-driven service discovery, introduced in AS3 3.9.0.
               
               With event-driven service discovery, you POST a declaration with the addressDiscovery property set to event. This creates a new endpoint which you can use to add nodes that does not require an AS3 declaration, so it can be more efficient than using PATCH or POST to add nodes.
               
               When you use the event value for addressDiscovery, the system creates the new endpoint with the following syntax: https://<host>/mgmt/shared/service-discovery/task/~<tenant name>~<application name>~<pool name>/nodes.
               
               For example, in the following declaration, assuming 192.0.2.14 is our BIG-IP, the endpoint that is created is: https://192.0.2.14/mgmt/shared/service-discovery/task/~Sample_event_sd~My_app~My_pool/nodes
               
               Once the endpoint is created( taskid ), you can use it to add nodes to the BIG-IP pool
               First we show the initial declaration to POST to the BIG-IP system.
               
               {
               "class": "ADC",
               "schemaVersion": "3.9.0",
               "id": "Pool",
               "Sample_event_sd": {
               "class": "Tenant",
               "My_app": {
               "class": "Application",
               "My_pool": {
               "class": "Pool",
               "members": [
               {
               "servicePort": 8080,
               "addressDiscovery": "static",
               "serverAddresses": [
               "192.0.2.2"
               ]
               },
               {
               "servicePort": 8080,
               "addressDiscovery": "event"
               }
               ]
               }
               }
               }
               }
               
               
               Once the declaration has been sent to the BIG-IP, we can use taskid/id ( ~Sample_event_sd~My_app~My_pool" ) and node list for the resource to dynamically update the node list.
        :param pulumi.Input[_builtins.str] taskid: servicediscovery endpoint ( Below example shows how to create endpoing using AS3 )
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _EventServiceDiscoveryState.__new__(_EventServiceDiscoveryState)

        __props__.__dict__["nodes"] = nodes
        __props__.__dict__["taskid"] = taskid
        return EventServiceDiscovery(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def nodes(self) -> pulumi.Output[Optional[Sequence['outputs.EventServiceDiscoveryNode']]]:
        """
        Map of node which will be added to pool which will be having node name(id),node address(ip) and node port(port)

        For more information, please refer below document
        https://clouddocs.f5.com/products/extensions/f5-appsvcs-extension/latest/declarations/discovery.html?highlight=service%20discovery#event-driven-service-discovery

        Below example shows how to use event-driven service discovery, introduced in AS3 3.9.0.

        With event-driven service discovery, you POST a declaration with the addressDiscovery property set to event. This creates a new endpoint which you can use to add nodes that does not require an AS3 declaration, so it can be more efficient than using PATCH or POST to add nodes.

        When you use the event value for addressDiscovery, the system creates the new endpoint with the following syntax: https://<host>/mgmt/shared/service-discovery/task/~<tenant name>~<application name>~<pool name>/nodes.

        For example, in the following declaration, assuming 192.0.2.14 is our BIG-IP, the endpoint that is created is: https://192.0.2.14/mgmt/shared/service-discovery/task/~Sample_event_sd~My_app~My_pool/nodes

        Once the endpoint is created( taskid ), you can use it to add nodes to the BIG-IP pool
        First we show the initial declaration to POST to the BIG-IP system.

        {
        "class": "ADC",
        "schemaVersion": "3.9.0",
        "id": "Pool",
        "Sample_event_sd": {
        "class": "Tenant",
        "My_app": {
        "class": "Application",
        "My_pool": {
        "class": "Pool",
        "members": [
        {
        "servicePort": 8080,
        "addressDiscovery": "static",
        "serverAddresses": [
        "192.0.2.2"
        ]
        },
        {
        "servicePort": 8080,
        "addressDiscovery": "event"
        }
        ]
        }
        }
        }
        }


        Once the declaration has been sent to the BIG-IP, we can use taskid/id ( ~Sample_event_sd~My_app~My_pool" ) and node list for the resource to dynamically update the node list.
        """
        return pulumi.get(self, "nodes")

    @_builtins.property
    @pulumi.getter
    def taskid(self) -> pulumi.Output[_builtins.str]:
        """
        servicediscovery endpoint ( Below example shows how to create endpoing using AS3 )
        """
        return pulumi.get(self, "taskid")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetCertificateResult',
    'AwaitableGetCertificateResult',
    'get_certificate',
    'get_certificate_output',
]

@pulumi.output_type
class GetCertificateResult:
    """
    A collection of values returned by getCertificate.
    """
    def __init__(__self__, certificate=None, id=None, name=None, partition=None):
        if certificate and not isinstance(certificate, str):
            raise TypeError("Expected argument 'certificate' to be a str")
        pulumi.set(__self__, "certificate", certificate)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if partition and not isinstance(partition, str):
            raise TypeError("Expected argument 'partition' to be a str")
        pulumi.set(__self__, "partition", partition)

    @_builtins.property
    @pulumi.getter
    def certificate(self) -> _builtins.str:
        return pulumi.get(self, "certificate")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        Name of ssl_certificate configured on bigip with full path
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def partition(self) -> _builtins.str:
        """
        Bigip partition in which ssl-certificate is configured
        """
        return pulumi.get(self, "partition")


class AwaitableGetCertificateResult(GetCertificateResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetCertificateResult(
            certificate=self.certificate,
            id=self.id,
            name=self.name,
            partition=self.partition)


def get_certificate(name: Optional[_builtins.str] = None,
                    partition: Optional[_builtins.str] = None,
                    opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetCertificateResult:
    """
    Use this data source (`ssl.Certificate`) to get the ssl-certificate details available on BIG-IP

    ## Example Usage

    ```python
    import pulumi
    import pulumi_f5bigip as f5bigip

    test = f5bigip.ssl.get_certificate(name="terraform_ssl_certificate",
        partition="Common")
    pulumi.export("bigipSslCertificateName", test.name)
    ```


    :param _builtins.str name: Name of the ssl_certificate
    :param _builtins.str partition: partition of the ltm ssl_certificate
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['partition'] = partition
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('f5bigip:ssl/getCertificate:getCertificate', __args__, opts=opts, typ=GetCertificateResult).value

    return AwaitableGetCertificateResult(
        certificate=pulumi.get(__ret__, 'certificate'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        partition=pulumi.get(__ret__, 'partition'))
def get_certificate_output(name: Optional[pulumi.Input[_builtins.str]] = None,
                           partition: Optional[pulumi.Input[_builtins.str]] = None,
                           opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetCertificateResult]:
    """
    Use this data source (`ssl.Certificate`) to get the ssl-certificate details available on BIG-IP

    ## Example Usage

    ```python
    import pulumi
    import pulumi_f5bigip as f5bigip

    test = f5bigip.ssl.get_certificate(name="terraform_ssl_certificate",
        partition="Common")
    pulumi.export("bigipSslCertificateName", test.name)
    ```


    :param _builtins.str name: Name of the ssl_certificate
    :param _builtins.str partition: partition of the ltm ssl_certificate
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['partition'] = partition
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('f5bigip:ssl/getCertificate:getCertificate', __args__, opts=opts, typ=GetCertificateResult)
    return __ret__.apply(lambda __response__: GetCertificateResult(
        certificate=pulumi.get(__response__, 'certificate'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        partition=pulumi.get(__response__, 'partition')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
from . import _utilities
import typing
# Export this package's modules as members:
from .as3 import *
from .big_iq_as3 import *
from .command import *
from .common_license_manage_big_iq import *
from .do import *
from .event_service_discovery import *
from .fast_application import *
from .fast_http_app import *
from .fast_https_app import *
from .fast_tcp_app import *
from .fast_template import *
from .fast_udp_app import *
from .get_as3_device_information import *
from .ipsec_policy import *
from .ipsec_profile import *
from .net_ike_peer import *
from .net_tunnel import *
from .partition import *
from .provider import *
from .saas_bot_defense_profile import *
from .ssl_key_cert import *
from .traffic_selector import *
from .waf_policy import *
from ._inputs import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_f5bigip.cm as __cm
    cm = __cm
    import pulumi_f5bigip.config as __config
    config = __config
    import pulumi_f5bigip.fast as __fast
    fast = __fast
    import pulumi_f5bigip.ltm as __ltm
    ltm = __ltm
    import pulumi_f5bigip.net as __net
    net = __net
    import pulumi_f5bigip.ssl as __ssl
    ssl = __ssl
    import pulumi_f5bigip.sys as __sys
    sys = __sys
    import pulumi_f5bigip.vcmp as __vcmp
    vcmp = __vcmp
else:
    cm = _utilities.lazy_import('pulumi_f5bigip.cm')
    config = _utilities.lazy_import('pulumi_f5bigip.config')
    fast = _utilities.lazy_import('pulumi_f5bigip.fast')
    ltm = _utilities.lazy_import('pulumi_f5bigip.ltm')
    net = _utilities.lazy_import('pulumi_f5bigip.net')
    ssl = _utilities.lazy_import('pulumi_f5bigip.ssl')
    sys = _utilities.lazy_import('pulumi_f5bigip.sys')
    vcmp = _utilities.lazy_import('pulumi_f5bigip.vcmp')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "f5bigip",
  "mod": "cm/device",
  "fqn": "pulumi_f5bigip.cm",
  "classes": {
   "f5bigip:cm/device:Device": "Device"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "cm/deviceGroup",
  "fqn": "pulumi_f5bigip.cm",
  "classes": {
   "f5bigip:cm/deviceGroup:DeviceGroup": "DeviceGroup"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "index/as3",
  "fqn": "pulumi_f5bigip",
  "classes": {
   "f5bigip:index/as3:As3": "As3"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "index/bigIqAs3",
  "fqn": "pulumi_f5bigip",
  "classes": {
   "f5bigip:index/bigIqAs3:BigIqAs3": "BigIqAs3"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "index/command",
  "fqn": "pulumi_f5bigip",
  "classes": {
   "f5bigip:index/command:Command": "Command"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "index/commonLicenseManageBigIq",
  "fqn": "pulumi_f5bigip",
  "classes": {
   "f5bigip:index/commonLicenseManageBigIq:CommonLicenseManageBigIq": "CommonLicenseManageBigIq"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "index/do",
  "fqn": "pulumi_f5bigip",
  "classes": {
   "f5bigip:index/do:Do": "Do"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "index/eventServiceDiscovery",
  "fqn": "pulumi_f5bigip",
  "classes": {
   "f5bigip:index/eventServiceDiscovery:EventServiceDiscovery": "EventServiceDiscovery"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "index/fastApplication",
  "fqn": "pulumi_f5bigip",
  "classes": {
   "f5bigip:index/fastApplication:FastApplication": "FastApplication"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "index/fastHttpApp",
  "fqn": "pulumi_f5bigip",
  "classes": {
   "f5bigip:index/fastHttpApp:FastHttpApp": "FastHttpApp"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "index/fastHttpsApp",
  "fqn": "pulumi_f5bigip",
  "classes": {
   "f5bigip:index/fastHttpsApp:FastHttpsApp": "FastHttpsApp"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "index/fastTcpApp",
  "fqn": "pulumi_f5bigip",
  "classes": {
   "f5bigip:index/fastTcpApp:FastTcpApp": "FastTcpApp"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "index/fastTemplate",
  "fqn": "pulumi_f5bigip",
  "classes": {
   "f5bigip:index/fastTemplate:FastTemplate": "FastTemplate"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "index/fastUdpApp",
  "fqn": "pulumi_f5bigip",
  "classes": {
   "f5bigip:index/fastUdpApp:FastUdpApp": "FastUdpApp"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "index/ipsecPolicy",
  "fqn": "pulumi_f5bigip",
  "classes": {
   "f5bigip:index/ipsecPolicy:IpsecPolicy": "IpsecPolicy"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "index/ipsecProfile",
  "fqn": "pulumi_f5bigip",
  "classes": {
   "f5bigip:index/ipsecProfile:IpsecProfile": "IpsecProfile"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "index/netIkePeer",
  "fqn": "pulumi_f5bigip",
  "classes": {
   "f5bigip:index/netIkePeer:NetIkePeer": "NetIkePeer"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "index/netTunnel",
  "fqn": "pulumi_f5bigip",
  "classes": {
   "f5bigip:index/netTunnel:NetTunnel": "NetTunnel"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "index/partition",
  "fqn": "pulumi_f5bigip",
  "classes": {
   "f5bigip:index/partition:Partition": "Partition"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "index/saasBotDefenseProfile",
  "fqn": "pulumi_f5bigip",
  "classes": {
   "f5bigip:index/saasBotDefenseProfile:SaasBotDefenseProfile": "SaasBotDefenseProfile"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "index/sslKeyCert",
  "fqn": "pulumi_f5bigip",
  "classes": {
   "f5bigip:index/sslKeyCert:SslKeyCert": "SslKeyCert"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "index/trafficSelector",
  "fqn": "pulumi_f5bigip",
  "classes": {
   "f5bigip:index/trafficSelector:TrafficSelector": "TrafficSelector"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "index/wafPolicy",
  "fqn": "pulumi_f5bigip",
  "classes": {
   "f5bigip:index/wafPolicy:WafPolicy": "WafPolicy"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "ltm/cipherGroup",
  "fqn": "pulumi_f5bigip.ltm",
  "classes": {
   "f5bigip:ltm/cipherGroup:CipherGroup": "CipherGroup"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "ltm/cipherRule",
  "fqn": "pulumi_f5bigip.ltm",
  "classes": {
   "f5bigip:ltm/cipherRule:CipherRule": "CipherRule"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "ltm/dataGroup",
  "fqn": "pulumi_f5bigip.ltm",
  "classes": {
   "f5bigip:ltm/dataGroup:DataGroup": "DataGroup"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "ltm/iRule",
  "fqn": "pulumi_f5bigip.ltm",
  "classes": {
   "f5bigip:ltm/iRule:IRule": "IRule"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "ltm/monitor",
  "fqn": "pulumi_f5bigip.ltm",
  "classes": {
   "f5bigip:ltm/monitor:Monitor": "Monitor"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "ltm/node",
  "fqn": "pulumi_f5bigip.ltm",
  "classes": {
   "f5bigip:ltm/node:Node": "Node"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "ltm/persistenceProfileCookie",
  "fqn": "pulumi_f5bigip.ltm",
  "classes": {
   "f5bigip:ltm/persistenceProfileCookie:PersistenceProfileCookie": "PersistenceProfileCookie"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "ltm/persistenceProfileDstAddr",
  "fqn": "pulumi_f5bigip.ltm",
  "classes": {
   "f5bigip:ltm/persistenceProfileDstAddr:PersistenceProfileDstAddr": "PersistenceProfileDstAddr"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "ltm/persistenceProfileSrcAddr",
  "fqn": "pulumi_f5bigip.ltm",
  "classes": {
   "f5bigip:ltm/persistenceProfileSrcAddr:PersistenceProfileSrcAddr": "PersistenceProfileSrcAddr"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "ltm/persistenceProfileSsl",
  "fqn": "pulumi_f5bigip.ltm",
  "classes": {
   "f5bigip:ltm/persistenceProfileSsl:PersistenceProfileSsl": "PersistenceProfileSsl"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "ltm/policy",
  "fqn": "pulumi_f5bigip.ltm",
  "classes": {
   "f5bigip:ltm/policy:Policy": "Policy"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "ltm/pool",
  "fqn": "pulumi_f5bigip.ltm",
  "classes": {
   "f5bigip:ltm/pool:Pool": "Pool"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "ltm/poolAttachment",
  "fqn": "pulumi_f5bigip.ltm",
  "classes": {
   "f5bigip:ltm/poolAttachment:PoolAttachment": "PoolAttachment"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "ltm/profileBotDefense",
  "fqn": "pulumi_f5bigip.ltm",
  "classes": {
   "f5bigip:ltm/profileBotDefense:ProfileBotDefense": "ProfileBotDefense"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "ltm/profileClientSsl",
  "fqn": "pulumi_f5bigip.ltm",
  "classes": {
   "f5bigip:ltm/profileClientSsl:ProfileClientSsl": "ProfileClientSsl"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "ltm/profileFastHttp",
  "fqn": "pulumi_f5bigip.ltm",
  "classes": {
   "f5bigip:ltm/profileFastHttp:ProfileFastHttp": "ProfileFastHttp"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "ltm/profileFastL4",
  "fqn": "pulumi_f5bigip.ltm",
  "classes": {
   "f5bigip:ltm/profileFastL4:ProfileFastL4": "ProfileFastL4"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "ltm/profileFtp",
  "fqn": "pulumi_f5bigip.ltm",
  "classes": {
   "f5bigip:ltm/profileFtp:ProfileFtp": "ProfileFtp"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "ltm/profileHttp",
  "fqn": "pulumi_f5bigip.ltm",
  "classes": {
   "f5bigip:ltm/profileHttp:ProfileHttp": "ProfileHttp"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "ltm/profileHttp2",
  "fqn": "pulumi_f5bigip.ltm",
  "classes": {
   "f5bigip:ltm/profileHttp2:ProfileHttp2": "ProfileHttp2"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "ltm/profileHttpCompress",
  "fqn": "pulumi_f5bigip.ltm",
  "classes": {
   "f5bigip:ltm/profileHttpCompress:ProfileHttpCompress": "ProfileHttpCompress"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "ltm/profileOneConnect",
  "fqn": "pulumi_f5bigip.ltm",
  "classes": {
   "f5bigip:ltm/profileOneConnect:ProfileOneConnect": "ProfileOneConnect"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "ltm/profileRewrite",
  "fqn": "pulumi_f5bigip.ltm",
  "classes": {
   "f5bigip:ltm/profileRewrite:ProfileRewrite": "ProfileRewrite"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "ltm/profileRewriteUriRules",
  "fqn": "pulumi_f5bigip.ltm",
  "classes": {
   "f5bigip:ltm/profileRewriteUriRules:ProfileRewriteUriRules": "ProfileRewriteUriRules"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "ltm/profileServerSsl",
  "fqn": "pulumi_f5bigip.ltm",
  "classes": {
   "f5bigip:ltm/profileServerSsl:ProfileServerSsl": "ProfileServerSsl"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "ltm/profileTcp",
  "fqn": "pulumi_f5bigip.ltm",
  "classes": {
   "f5bigip:ltm/profileTcp:ProfileTcp": "ProfileTcp"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "ltm/profileWebAcceleration",
  "fqn": "pulumi_f5bigip.ltm",
  "classes": {
   "f5bigip:ltm/profileWebAcceleration:ProfileWebAcceleration": "ProfileWebAcceleration"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "ltm/requestLogProfile",
  "fqn": "pulumi_f5bigip.ltm",
  "classes": {
   "f5bigip:ltm/requestLogProfile:RequestLogProfile": "RequestLogProfile"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "ltm/snat",
  "fqn": "pulumi_f5bigip.ltm",
  "classes": {
   "f5bigip:ltm/snat:Snat": "Snat"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "ltm/snatPool",
  "fqn": "pulumi_f5bigip.ltm",
  "classes": {
   "f5bigip:ltm/snatPool:SnatPool": "SnatPool"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "ltm/virtualAddress",
  "fqn": "pulumi_f5bigip.ltm",
  "classes": {
   "f5bigip:ltm/virtualAddress:VirtualAddress": "VirtualAddress"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "ltm/virtualServer",
  "fqn": "pulumi_f5bigip.ltm",
  "classes": {
   "f5bigip:ltm/virtualServer:VirtualServer": "VirtualServer"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "net/route",
  "fqn": "pulumi_f5bigip.net",
  "classes": {
   "f5bigip:net/route:Route": "Route"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "net/selfIp",
  "fqn": "pulumi_f5bigip.net",
  "classes": {
   "f5bigip:net/selfIp:SelfIp": "SelfIp"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "net/vlan",
  "fqn": "pulumi_f5bigip.net",
  "classes": {
   "f5bigip:net/vlan:Vlan": "Vlan"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "ssl/certificate",
  "fqn": "pulumi_f5bigip.ssl",
  "classes": {
   "f5bigip:ssl/certificate:Certificate": "Certificate"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "ssl/key",
  "fqn": "pulumi_f5bigip.ssl",
  "classes": {
   "f5bigip:ssl/key:Key": "Key"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "sys/bigIpLicense",
  "fqn": "pulumi_f5bigip.sys",
  "classes": {
   "f5bigip:sys/bigIpLicense:BigIpLicense": "BigIpLicense"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "sys/dns",
  "fqn": "pulumi_f5bigip.sys",
  "classes": {
   "f5bigip:sys/dns:Dns": "Dns"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "sys/iApp",
  "fqn": "pulumi_f5bigip.sys",
  "classes": {
   "f5bigip:sys/iApp:IApp": "IApp"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "sys/ntp",
  "fqn": "pulumi_f5bigip.sys",
  "classes": {
   "f5bigip:sys/ntp:Ntp": "Ntp"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "sys/ocsp",
  "fqn": "pulumi_f5bigip.sys",
  "classes": {
   "f5bigip:sys/ocsp:Ocsp": "Ocsp"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "sys/provision",
  "fqn": "pulumi_f5bigip.sys",
  "classes": {
   "f5bigip:sys/provision:Provision": "Provision"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "sys/snmp",
  "fqn": "pulumi_f5bigip.sys",
  "classes": {
   "f5bigip:sys/snmp:Snmp": "Snmp"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "sys/snmpTraps",
  "fqn": "pulumi_f5bigip.sys",
  "classes": {
   "f5bigip:sys/snmpTraps:SnmpTraps": "SnmpTraps"
  }
 },
 {
  "pkg": "f5bigip",
  "mod": "vcmp/guest",
  "fqn": "pulumi_f5bigip.vcmp",
  "classes": {
   "f5bigip:vcmp/guest:Guest": "Guest"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "f5bigip",
  "token": "pulumi:providers:f5bigip",
  "fqn": "pulumi_f5bigip",
  "class": "Provider"
 }
]
"""
)



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetWafPolicyResult',
    'AwaitableGetWafPolicyResult',
    'get_waf_policy',
    'get_waf_policy_output',
]

@pulumi.output_type
class GetWafPolicyResult:
    """
    A collection of values returned by getWafPolicy.
    """
    def __init__(__self__, id=None, policy_id=None, policy_json=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if policy_id and not isinstance(policy_id, str):
            raise TypeError("Expected argument 'policy_id' to be a str")
        pulumi.set(__self__, "policy_id", policy_id)
        if policy_json and not isinstance(policy_json, str):
            raise TypeError("Expected argument 'policy_json' to be a str")
        pulumi.set(__self__, "policy_json", policy_json)

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="policyId")
    def policy_id(self) -> _builtins.str:
        return pulumi.get(self, "policy_id")

    @_builtins.property
    @pulumi.getter(name="policyJson")
    def policy_json(self) -> _builtins.str:
        """
        Exported WAF policy JSON
        """
        return pulumi.get(self, "policy_json")


class AwaitableGetWafPolicyResult(GetWafPolicyResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetWafPolicyResult(
            id=self.id,
            policy_id=self.policy_id,
            policy_json=self.policy_json)


def get_waf_policy(policy_id: Optional[_builtins.str] = None,
                   policy_json: Optional[_builtins.str] = None,
                   opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetWafPolicyResult:
    """
    Use this data source (`WafPolicy`) to get the details of exist WAF policy BIG-IP.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_f5bigip as f5bigip

    existpolicy = f5bigip.ssl.get_waf_policy(policy_id="xxxxx")
    ```


    :param _builtins.str policy_id: ID of the WAF policy deployed in the BIG-IP.
    :param _builtins.str policy_json: Exported WAF policy JSON
    """
    __args__ = dict()
    __args__['policyId'] = policy_id
    __args__['policyJson'] = policy_json
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('f5bigip:ssl/getWafPolicy:getWafPolicy', __args__, opts=opts, typ=GetWafPolicyResult).value

    return AwaitableGetWafPolicyResult(
        id=pulumi.get(__ret__, 'id'),
        policy_id=pulumi.get(__ret__, 'policy_id'),
        policy_json=pulumi.get(__ret__, 'policy_json'))
def get_waf_policy_output(policy_id: Optional[pulumi.Input[_builtins.str]] = None,
                          policy_json: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                          opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetWafPolicyResult]:
    """
    Use this data source (`WafPolicy`) to get the details of exist WAF policy BIG-IP.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_f5bigip as f5bigip

    existpolicy = f5bigip.ssl.get_waf_policy(policy_id="xxxxx")
    ```


    :param _builtins.str policy_id: ID of the WAF policy deployed in the BIG-IP.
    :param _builtins.str policy_json: Exported WAF policy JSON
    """
    __args__ = dict()
    __args__['policyId'] = policy_id
    __args__['policyJson'] = policy_json
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('f5bigip:ssl/getWafPolicy:getWafPolicy', __args__, opts=opts, typ=GetWafPolicyResult)
    return __ret__.apply(lambda __response__: GetWafPolicyResult(
        id=pulumi.get(__response__, 'id'),
        policy_id=pulumi.get(__response__, 'policy_id'),
        policy_json=pulumi.get(__response__, 'policy_json')))
